==> debestia8.3-0.3b1pl2.zip: debestia8.3-0.3b1pl2/data/npc/scripts/boatztrup.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)



-- OTServ event handling functions start
function onCreatureAppear(cid)				npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) 			npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) 	npcHandler:onCreatureSay(cid, type, msg) end
function onThink() 						npcHandler:onThink() end
-- OTServ event handling functions end

function creatureSayCallback(cid, type, msg)
	msg = string.lower(msg)
	if msgcontains(msg, 'zabierz mnie do') or msgcontains(msg, 'bring me to') then
	if getPlayerPzLock(cid) == 1 then
		doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, "Kapitan statku: Nie plywam z osobami ktore dopiero co walczyly.")
		return true
	end
		if msgcontains(msg, 'kiobios') then
			to_destinationz = {cost = 1000, toPosition = {x=292, y=791, z=7}, premium = 0}
		else
			return true
		end
		if(getPlayerPremiumDays(cid) > 0 or to_destinationz.premium == 0) and (getPlayerPzLock(cid) == 0)then
			if(doPlayerRemoveMoney(cid, to_destinationz.cost) == TRUE) then
				doTeleportThing(cid, to_destinationz.toPosition, 0)
				doSendMagicEffect(to_destinationz.toPosition, 10)
			end
		end
	end
	return true
end
npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)

-- Don't forget npcHandler = npcHandler in the parameters. It is required for all StdModule functions!
local travelNode = keywordHandler:addKeyword({'kiobios'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Chcesz poplynac do portu niedaleko Kiobios za 500 zlotych monet?'})
	travelNode:addChildKeyword({'yes'}, StdModule.travel, {npcHandler = npcHandler, premium = false, level = 5, cost = 500, destination = {x=292, y=791, z=7} })
	travelNode:addChildKeyword({'tak'}, StdModule.travel, {npcHandler = npcHandler, premium = false, level = 5, cost = 500, destination = {x=292, y=791, z=7} })
	travelNode:addChildKeyword({'no'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Taniej nie poplyne. Innego wyjscia nie znajdziesz.'})
	travelNode:addChildKeyword({'nie'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Taniej nie poplyne. Innego wyjscia nie znajdziesz.'})
keywordHandler:addKeyword({'trip'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Moge z Toba plynac do portu niedaleko \'Kiobios\' za 500 zlotych monet.'})

-- Makes sure the npc reacts when you say hi, bye etc.
npcHandler:addModule(FocusModule:new())

==> debestia8.4-0.3.1pl2.zip: debestia8.4-0.3.1pl2/data/npc/scripts/boatztrup.lua <==
local keywordHandler = KeywordHandler:new()
local npcHandler = NpcHandler:new(keywordHandler)
NpcSystem.parseParameters(npcHandler)



-- OTServ event handling functions start
function onCreatureAppear(cid)				npcHandler:onCreatureAppear(cid) end
function onCreatureDisappear(cid) 			npcHandler:onCreatureDisappear(cid) end
function onCreatureSay(cid, type, msg) 	npcHandler:onCreatureSay(cid, type, msg) end
function onThink() 						npcHandler:onThink() end
-- OTServ event handling functions end

function creatureSayCallback(cid, type, msg)
	msg = string.lower(msg)
	if msgcontains(msg, 'zabierz mnie do') or msgcontains(msg, 'bring me to') then
		if (getPlayerPzLock(cid) == 1) then
			doPlayerSendTextMessage(cid, MESSAGE_STATUS_CONSOLE_BLUE, "Nie plywam z osobami tuz po walce. Jeszcze bys mi uszkodzil statek!")
			return true
		end
		if msgcontains(msg, 'kiobios') then
			to_destinationz = {cost = 1000, toPosition = {x=292, y=791, z=7}, premium = 0}
		else
			return true
		end
		if(getPlayerPremiumDays(cid) > 0 or to_destinationz.premium == 0) and (getPlayerPzLock(cid) == 0)then
			if(doPlayerRemoveMoney(cid, to_destinationz.cost) == TRUE) then
				doTeleportThing(cid, to_destinationz.toPosition, 0)
				doSendMagicEffect(to_destinationz.toPosition, 10)
			end
		end
	end
	return true
end
npcHandler:setCallback(CALLBACK_MESSAGE_DEFAULT, creatureSayCallback)

-- Don't forget npcHandler = npcHandler in the parameters. It is required for all StdModule functions!
local travelNode = keywordHandler:addKeyword({'kiobios'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Chcesz poplynac do portu niedaleko Kiobios za 500 zlotych monet?'})
	travelNode:addChildKeyword({'yes'}, StdModule.travel, {npcHandler = npcHandler, premium = false, level = 5, cost = 500, destination = {x=292, y=791, z=7} })
	travelNode:addChildKeyword({'tak'}, StdModule.travel, {npcHandler = npcHandler, premium = false, level = 5, cost = 500, destination = {x=292, y=791, z=7} })
	travelNode:addChildKeyword({'no'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Taniej nie poplyne. Innego wyjscia nie znajdziesz.'})
	travelNode:addChildKeyword({'nie'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, reset = true, text = 'Taniej nie poplyne. Innego wyjscia nie znajdziesz.'})
keywordHandler:addKeyword({'trip'}, StdModule.say, {npcHandler = npcHandler, onlyFocus = true, text = 'Moge z Toba plynac do portu niedaleko \'Kiobios\' za 500 zlotych monet.'})

-- Makes sure the npc reacts when you say hi, bye etc.
npcHandler:addModule(FocusModule:new())
